@@ -10,7 +10,9 @@
 
 #include <QSharedPointer>
 
-#include <syndication_export.h>
+#include "../syndication_export.h"
+
+#include <memory>
 
 class QString;
 
@@ -59,7 +61,7 @@ private:
     Q_DISABLE_COPY(ContentVocab)
 
     class ContentVocabPrivate;
-    ContentVocabPrivate *const d;
+    std::unique_ptr<ContentVocabPrivate> const d;
 };
 
 } // namespace RDF
