@@ -10,7 +10,7 @@
 
 #include <QSharedPointer>
 
-#include <syndication_export.h>
+#include "../syndication_export.h"
 
 class QDomDocument;
 class QDomElement;
@@ -19,7 +19,6 @@ namespace Syndication
 {
 namespace RDF
 {
-
 class Model;
 class Resource;
 //@cond PRIVATE
@@ -43,7 +42,7 @@ public:
     Model createFromXML(const QDomDocument &doc);
 
 private:
-    ResourcePtr readResource(Model &model, const QDomElement &el);
+    SYNDICATION_NO_EXPORT ResourcePtr readResource(Model &model, const QDomElement &el);
 };
 
 } // namespace RDF
