@@ -65,6 +65,10 @@ uint parseISODate(const QString &str)
 uint parseRFCDate(const QString &str)
 {
     QDateTime kdt = QDateTime::fromString(str, Qt::RFC2822Date);
+    // Qt5 used to ignore invalid textual offsets but Qt6 rejects those, so handle that explictly
+    if (!kdt.isValid() && str.endsWith(QLatin1String(" GMT"))) {
+        kdt = QDateTime::fromString(QStringView(str).chopped(4), Qt::RFC2822Date);
+    }
     return toTimeT(kdt);
 }
 
